'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.tildify = tildify;
exports.selectTitleAttributes = selectTitleAttributes;
exports.setTitleFromAttributes = setTitleFromAttributes;
exports.initNativeHandlers = initNativeHandlers;

var _electron = require('electron');

var _homeDir = require('home-dir');

var _homeDir2 = _interopRequireDefault(_homeDir);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _Rx = require('rxjs/Rx');

var _Rx2 = _interopRequireDefault(_Rx);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const HOME = (0, _homeDir2.default)();
const { getCurrentWindow } = _electron.remote;

/**
 * Turn a path like /Users/n/mine.ipynb to ~/mine.ipynb
 * @param  {string} p the full path to a file
 * @return {string}   tildified path
 */
function tildify(p) {
  if (!p) {
    return '';
  }
  const s = _path2.default.normalize(p) + _path2.default.sep;
  return (s.indexOf(HOME) === 0 ? s.replace(HOME + _path2.default.sep, `~${ _path2.default.sep }`) : s).slice(0, -1);
}

function selectTitleAttributes(state) {
  return {
    modified: state.app.get('modified'),
    executionState: state.app.get('executionState'),
    filename: state.metadata.get('filename') || 'Untitled',
    displayName: state.document.getIn(['notebook', 'metadata', 'kernelspec', 'display_name'], '...')
  };
}

function setTitleFromAttributes(attributes) {
  const filename = tildify(attributes.filename);
  const { modified, executionState, displayName } = attributes;

  const title = `${ filename } - ${ displayName } - ${ executionState }`;

  const win = getCurrentWindow();
  // TODO: Investigate if setRepresentedFilename() is a no-op on non-OS X
  if (filename && win.setRepresentedFilename) {
    // TODO: this needs to be the full path to the file
    win.setRepresentedFilename(filename);
  }
  if (win.setDocumentEdited) {
    win.setDocumentEdited(attributes.modified);
  }
  win.setTitle(title);
}

function initNativeHandlers(store) {
  const state$ = _Rx2.default.Observable.from(store);

  state$.map(selectTitleAttributes).distinctUntilChanged().switchMap(i => _Rx2.default.Observable.of(i)).debounceTime(200).subscribe(setTitleFromAttributes, err => console.error(err));
}